# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class EndpointSlice(pulumi.CustomResource):
    """
    EndpointSlice represents a subset of the endpoints that implement a service. For a given service
    there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce
    the full set of endpoints.
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    address_type: pulumi.Output[str]
    """
    addressType specifies the type of address carried by this EndpointSlice. All addresses in this
    slice must be the same type. This field is immutable after creation. The following address types
    are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address.
    * FQDN: Represents a Fully Qualified Domain Name.
    """

    endpoints: pulumi.Output[list]
    """
    endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000
    endpoints.
    """

    metadata: pulumi.Output[dict]
    """
    Standard object's metadata.
    """

    ports: pulumi.Output[list]
    """
    ports specifies the list of network ports exposed by each endpoint in this slice. Each port must
    have a unique name. When ports is empty, it indicates that there are no defined ports. When a
    port is defined with a nil port value, it indicates "all ports". Each slice may include a
    maximum of 100 ports.
    """

    def __init__(self, resource_name, opts=None, address_type=None, endpoints=None, metadata=None, ports=None, __name__=None, __opts__=None):
        """
        Create a EndpointSlice resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[str] address_type: addressType specifies the type of address carried by this EndpointSlice. All
               addresses in this slice must be the same type. This field is immutable after
               creation. The following address types are currently supported: * IPv4: Represents an
               IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully
               Qualified Domain Name.
        :param pulumi.Input[list] endpoints: endpoints is a list of unique endpoints in this slice. Each slice may include a
               maximum of 1000 endpoints.
        :param pulumi.Input[dict] metadata: Standard object's metadata.
        :param pulumi.Input[list] ports: ports specifies the list of network ports exposed by each endpoint in this slice.
               Each port must have a unique name. When ports is empty, it indicates that there are
               no defined ports. When a port is defined with a nil port value, it indicates "all
               ports". Each slice may include a maximum of 100 ports.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'discovery.k8s.io/v1beta1'
        __props__['kind'] = 'EndpointSlice'
        if address_type is None:
            raise TypeError('Missing required property address_type')
        __props__['addressType'] = address_type
        if endpoints is None:
            raise TypeError('Missing required property endpoints')
        __props__['endpoints'] = endpoints
        __props__['metadata'] = metadata
        __props__['ports'] = ports

        __props__['status'] = None

        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
        ))

        super(EndpointSlice, self).__init__(
            "kubernetes:discovery.k8s.io/v1beta1:EndpointSlice",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `EndpointSlice` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return EndpointSlice(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import errno

from subprocess import check_call

from setuptools import setup, find_packages
from setuptools.command.install import install

class InstallPluginCommand(install):
    def run(self):
        install.run(self)
        try:
            check_call(['pulumi', 'plugin', 'install', 'resource', 'kubernetes', 'v1.7.0-alpha.1585855657+g83777b4f'])
        except OSError as error:
            if error.errno == errno.ENOENT:
                print("""
                There was an error installing the kubernetes resource provider plugin.
                It looks like `pulumi` is not installed on your system.
                Please visit https://pulumi.com/ to install the Pulumi CLI.
                You may try manually installing the plugin by running
                `pulumi plugin install resource kubernetes v1.7.0-alpha.1585855657+g83777b4f`
                """)
            else:
                raise


def readme():
    with open('README.md', 'r') as f:
        return f.read()


setup(name='pulumi_kubernetes',
      version='1.7.0a1585855657',
      description='A Pulumi package for creating and managing Kubernetes resources.',
      long_description=readme(),
      long_description_content_type='text/markdown',
      cmdclass={
          'install': InstallPluginCommand,
      },
      keywords='pulumi kubernetes',
      url='https://pulumi.io',
      project_urls={
          'Repository': 'https://github.com/pulumi/pulumi-kubernetes'
      },
      license='Apache-2.0',
      packages=find_packages(),
      install_requires=[
          'pulumi>=2.0.0b0,<3.0.0',
          'requests>=2.21.0,<2.22.0',
          'semver>=2.8.1',
          'parver>=0.2.1',
      ],
      zip_safe=False)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .Binding import (Binding)
from .ComponentStatus import (ComponentStatus)
from .ComponentStatusList import (ComponentStatusList)
from .ConfigMap import (ConfigMap)
from .ConfigMapList import (ConfigMapList)
from .Endpoints import (Endpoints)
from .EndpointsList import (EndpointsList)
from .Event import (Event)
from .EventList import (EventList)
from .LimitRange import (LimitRange)
from .LimitRangeList import (LimitRangeList)
from .Namespace import (Namespace)
from .NamespaceList import (NamespaceList)
from .Node import (Node)
from .NodeList import (NodeList)
from .PersistentVolume import (PersistentVolume)
from .PersistentVolumeClaim import (PersistentVolumeClaim)
from .PersistentVolumeClaimList import (PersistentVolumeClaimList)
from .PersistentVolumeList import (PersistentVolumeList)
from .Pod import (Pod)
from .PodList import (PodList)
from .PodTemplate import (PodTemplate)
from .PodTemplateList import (PodTemplateList)
from .ReplicationController import (ReplicationController)
from .ReplicationControllerList import (ReplicationControllerList)
from .ResourceQuota import (ResourceQuota)
from .ResourceQuotaList import (ResourceQuotaList)
from .Secret import (Secret)
from .SecretList import (SecretList)
from .Service import (Service)
from .ServiceAccount import (ServiceAccount)
from .ServiceAccountList import (ServiceAccountList)
from .ServiceList import (ServiceList)



# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class RuntimeClass(pulumi.CustomResource):
    """
    RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is
    used to determine which container runtime is used to run all containers in a pod. RuntimeClasses
    are (currently) manually defined by a user or cluster provisioner, and referenced in the
    PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running
    the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/runtime-class.md
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    handler: pulumi.Output[str]
    """
    Handler specifies the underlying runtime and configuration that the CRI implementation will use
    to handle pods of this class. The possible values are specific to the node & CRI configuration.
    It is assumed that all handlers are available on every node, and handlers of the same name are
    equivalent on every node. For example, a handler called "runc" might specify that the runc OCI
    runtime (using native Linux containers) will be used to run the containers in a pod. The Handler
    must conform to the DNS Label (RFC 1123) requirements, and is immutable.
    """

    metadata: pulumi.Output[dict]
    """
    More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """

    overhead: pulumi.Output[dict]
    """
    Overhead represents the resource overhead associated with running a pod for a given
    RuntimeClass. For more details, see
    https://git.k8s.io/enhancements/keps/sig-node/20190226-pod-overhead.md This field is alpha-level
    as of Kubernetes v1.15, and is only honored by servers that enable the PodOverhead feature.
    """

    scheduling: pulumi.Output[dict]
    """
    Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass
    are scheduled to nodes that support it. If scheduling is nil, this RuntimeClass is assumed to be
    supported by all nodes.
    """

    def __init__(self, resource_name, opts=None, handler=None, metadata=None, overhead=None, scheduling=None, __name__=None, __opts__=None):
        """
        Create a RuntimeClass resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[str] handler: Handler specifies the underlying runtime and configuration that the CRI
               implementation will use to handle pods of this class. The possible values are
               specific to the node & CRI configuration.  It is assumed that all handlers are
               available on every node, and handlers of the same name are equivalent on every node.
               For example, a handler called "runc" might specify that the runc OCI runtime (using
               native Linux containers) will be used to run the containers in a pod. The Handler
               must conform to the DNS Label (RFC 1123) requirements, and is immutable.
        :param pulumi.Input[dict] metadata: More info:
               https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        :param pulumi.Input[dict] overhead: Overhead represents the resource overhead associated with running a pod for a given
               RuntimeClass. For more details, see
               https://git.k8s.io/enhancements/keps/sig-node/20190226-pod-overhead.md This field is
               alpha-level as of Kubernetes v1.15, and is only honored by servers that enable the
               PodOverhead feature.
        :param pulumi.Input[dict] scheduling: Scheduling holds the scheduling constraints to ensure that pods running with this
               RuntimeClass are scheduled to nodes that support it. If scheduling is nil, this
               RuntimeClass is assumed to be supported by all nodes.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'node.k8s.io/v1beta1'
        __props__['kind'] = 'RuntimeClass'
        if handler is None:
            raise TypeError('Missing required property handler')
        __props__['handler'] = handler
        __props__['metadata'] = metadata
        __props__['overhead'] = overhead
        __props__['scheduling'] = scheduling

        __props__['status'] = None

        parent = opts.parent if opts and opts.parent else None
        aliases = [
            pulumi.Alias(type_="kubernetes:node.k8s.io/v1alpha1:RuntimeClass"),
        ]
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
            aliases=aliases,
        ))

        super(RuntimeClass, self).__init__(
            "kubernetes:node.k8s.io/v1beta1:RuntimeClass",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `RuntimeClass` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return RuntimeClass(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class StorageClass(pulumi.CustomResource):
    """
    StorageClass describes the parameters for a class of storage for which PersistentVolumes can be
    dynamically provisioned.
    
    StorageClasses are non-namespaced; the name of the storage class according to etcd is in
    ObjectMeta.Name.
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    allow_volume_expansion: pulumi.Output[bool]
    """
    AllowVolumeExpansion shows whether the storage class allow volume expand
    """

    allowed_topologies: pulumi.Output[list]
    """
    Restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin
    defines its own supported topology specifications. An empty TopologySelectorTerm list means
    there is no topology restriction. This field is only honored by servers that enable the
    VolumeScheduling feature.
    """

    metadata: pulumi.Output[dict]
    """
    Standard object's metadata. More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """

    mount_options: pulumi.Output[list]
    """
    Dynamically provisioned PersistentVolumes of this storage class are created with these
    mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is
    invalid.
    """

    parameters: pulumi.Output[dict]
    """
    Parameters holds the parameters for the provisioner that should create volumes of this storage
    class.
    """

    provisioner: pulumi.Output[str]
    """
    Provisioner indicates the type of the provisioner.
    """

    reclaim_policy: pulumi.Output[str]
    """
    Dynamically provisioned PersistentVolumes of this storage class are created with this
    reclaimPolicy. Defaults to Delete.
    """

    volume_binding_mode: pulumi.Output[str]
    """
    VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.  When
    unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the
    VolumeScheduling feature.
    """

    def __init__(self, resource_name, opts=None, provisioner=None, allow_volume_expansion=None, allowed_topologies=None, metadata=None, mount_options=None, parameters=None, reclaim_policy=None, volume_binding_mode=None, __name__=None, __opts__=None):
        """
        Create a StorageClass resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[str] provisioner: Provisioner indicates the type of the provisioner.
        :param pulumi.Input[bool] allow_volume_expansion: AllowVolumeExpansion shows whether the storage class allow volume expand
        :param pulumi.Input[list] allowed_topologies: Restrict the node topologies where volumes can be dynamically provisioned. Each
               volume plugin defines its own supported topology specifications. An empty
               TopologySelectorTerm list means there is no topology restriction. This field is only
               honored by servers that enable the VolumeScheduling feature.
        :param pulumi.Input[dict] metadata: Standard object's metadata. More info:
               https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        :param pulumi.Input[list] mount_options: Dynamically provisioned PersistentVolumes of this storage class are created with
               these mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply
               fail if one is invalid.
        :param pulumi.Input[dict] parameters: Parameters holds the parameters for the provisioner that should create volumes of
               this storage class.
        :param pulumi.Input[str] reclaim_policy: Dynamically provisioned PersistentVolumes of this storage class are created with this
               reclaimPolicy. Defaults to Delete.
        :param pulumi.Input[str] volume_binding_mode: VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and
               bound.  When unset, VolumeBindingImmediate is used. This field is only honored by
               servers that enable the VolumeScheduling feature.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'storage.k8s.io/v1beta1'
        __props__['kind'] = 'StorageClass'
        if provisioner is None:
            raise TypeError('Missing required property provisioner')
        __props__['provisioner'] = provisioner
        __props__['allowVolumeExpansion'] = allow_volume_expansion
        __props__['allowedTopologies'] = allowed_topologies
        __props__['metadata'] = metadata
        __props__['mountOptions'] = mount_options
        __props__['parameters'] = parameters
        __props__['reclaimPolicy'] = reclaim_policy
        __props__['volumeBindingMode'] = volume_binding_mode

        __props__['status'] = None

        parent = opts.parent if opts and opts.parent else None
        aliases = [
            pulumi.Alias(type_="kubernetes:storage.k8s.io/v1:StorageClass"),
        ]
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
            aliases=aliases,
        ))

        super(StorageClass, self).__init__(
            "kubernetes:storage.k8s.io/v1beta1:StorageClass",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `StorageClass` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return StorageClass(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop
